@@ -15,7 +15,7 @@ console = Console()
 class FastAPIProjectGenerator:
     """Generate simple FastAPI projects with dependency injection."""
     
-    def __init__(self, config: Dict[str, Any]):
+    def __init__(self, config: Dict[str, str]):
         self.config = config
         self.project_name = config["project_name"]
         self.project_dir = Path.cwd() / self.project_name
